/**
 * This module contains some functions to handle profiles
 */
var DAProfiles = (function(){

	"use strict";

	/**
	 * Constructor
	 */
	function _DAProfiles() {}

	/**
	 * Checks if the stored profiles need to be updated.
	 * - check if passwords are encrypted. Any password
	 *   that is not encrypted will be encrypted.
	 * - check if rememberPassword is existent. If not add it.
	 */
	_DAProfiles.prototype.updateProfiles = function() {
		var settingsUpdated = false;

		// Profiles are stored in settings which are stored in the
		// global variable (global.settings)
		for ( let profileId in global.settings.profiles ){
			if ( global.settings.profiles.hasOwnProperty(profileId) ){
				let profile = global.settings.profiles[profileId];
				if ( profile.passwordEncryption !== DAEncryption.getVersion()
					&& profile.authType !== 'sso' ){

					// Password unencrypted or encrypted with older version, so let's encrypt it
					// with the latest version of the encryption module.
					var password = global.settings.profiles[profileId].requestOptions.form.password;

					// If the password is encrypted with an older version of the encryption
					// module, we must decrypt the password with that versions decrypt
					// method first!
					if ( typeof profile.passwordEncryption !== "undefined" ){
						password = DAEncryption[profile.passwordEncryption].decrypt(password);
					}

					// Encrypt the password and store the encryption version
					global.settings.profiles[profileId].requestOptions.form.password = DAEncryption.encrypt(password);
					global.settings.profiles[profileId].passwordEncryption = DAEncryption.getVersion();

					settingsUpdated = true;
				}

				if (!profile.hasOwnProperty('rememberPassword')) {
					global.settings.profiles[profileId].rememberPassword = true;
					settingsUpdated = true;
				}
			}
		}

		// Save the settings if any passwords were updated
		if ( settingsUpdated ){
			global.DA.saveSettings();
		}
	}

	return new _DAProfiles();
})();
